from collections import UserList
import os

from sqlalchemy import case

from auth import login_required, bp as auth_bp
from deck import probabilistic_deck_generator, bp as deck_bp
from menu import bp as menu_bp
from flask import Flask, redirect, render_template, session, request, url_for

from create_db import Card
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from config import CONFIG 

from get_public_links import test_file


engine = create_engine(CONFIG['DB_CONNECTION'])
dbsessionmaker = sessionmaker(bind=engine)
dbsession = dbsessionmaker()

deck_index=-1

def create_app(test_config=None):
    # create and configure the app
    app = Flask(__name__, instance_relative_config=True)
    app.config.from_mapping(
        SECRET_KEY='dev',
        DATABASE=os.path.join(app.instance_path, 'flaskr.sqlite'),
    )                                                                # = kaj naj tu piše?

    if test_config is None:
        # load the instance config, if it exists, when not testing
        app.config.from_pyfile('config.py', silent=True)
    else:
        # load the test config if passed in
        app.config.from_mapping(test_config)

    # ensure the instance folder exists
    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass


    @app.route('/')
    @login_required
    def index():
        return 'redirecting' # meče skoz nazaj na login TODO


    #@login_required
    @app.route('/deck/index', methods=("GET", "POST"))
    def deck():
        if 'user_id' in session:
            global deck_index
            user_id = session['user_id']
            username = session['username']
            d = probabilistic_deck_generator(user_id, 5, 5) #to je hell ker vsakič generira nov deck TODO deck bi moral bit nekako stabilen
            
            deck_index+=1
            if deck_index < len(d):
                card = d[deck_index]
            else:
                deck_index =-1
                return redirect(url_for("menu.index"))

            if request.method == 'POST':
                rate = request.form['rate']
                cardtitle = request
                print(rate)
                if rate == "Yes":
                    k = 1
                    dbsession.query(Card).filter(Card.id == card.id).update({'interest_rate': 1})
                elif rate == "Maybe":
                    k = 0.5
                    dbsession.query(Card).filter(Card.id == card.id).update({'interest_rate': abs(card.interest_rate*k)}) #TODO 1 mora nastavit na 1
                elif rate == "No":
                    k = 0.1
                    dbsession.query(Card).filter(Card.id == card.id).update({'interest_rate': abs(card.interest_rate*k)}) #TODO 1 mora nastavit na 1
    
                print(card.id)
                print(user_id)
                dbsession.commit()  
            return render_template("deck/index.html", username=username, card = card) # no idea kaj se tu dogaja...
        else:
            return index()


    @app.route('/logout')
    def logout():
        session.pop("user_id", None)
        return index()


    @app.route('/match')
    def match():
        return "match"

    @app.route('/upload')
    def upload():
        return "upload"
    
    
    #app.register_blueprint(bp) # ??
    app.register_blueprint(auth_bp)
    app.register_blueprint(deck_bp)
    app.register_blueprint(menu_bp)
    app.add_url_rule('/', endpoint='index')

    return app


app = create_app()
app.run(debug=True, host="0.0.0.0")